==> j2e.1.4.tar.gz: jhonyakuf.c <==
// jhonyakuf.c
//
#include <string.h>
#include <stdio.h>
#include <ctype.h>
#include "macro.h"

#define iskanji(c) ((c)>=0x81 && (c)<=0x9f || (c)>=0xe0 && (c)<=0xfc)
#define iskanji2(c) ((c)>=0x40 && (c)<=0x7e || (c)>=0x80 && (c)<=0xfc)

//extern char *dir;
extern FILE *dbg;
extern char Dbg;
extern int  wnb;
extern char cj[][JSentLen];

isVowel(char c)
{
    int  j = 0;
    if(c == 'a' || c == 'e' || c == 'i' || c == 'o' || c == 'u') j = 1;
    if(c == 'A' || c == 'E' || c == 'I' || c == 'O' || c == 'U') j = 1;
    return(j);
}

ptcpy(c, pt1, pt2)
char c[], *pt1, *pt2;
{
     char *pt;
     pt = pt1;
     while(pt != pt2) *(c++) = *(pt++);
    *c = '\0';
}

wdcpy(char *st1, char *st2)
{
    while(*st2 && (*st2 != ' ')) *st1++ = *st2++;
    *st1 = '\0';
}

cutoff(a, x, i)
char *a;
int  x, i;
{
    int  ln;
    char *b;
    ln = strlen(a);
    if(x < ln){
      b = a+x+i;	*(a+x) = '\0';
      if(ln > x+1) strcat(a, b);
    }
}

ptcut(pt, i)
char *pt;
int  i;
{
    char *pta, *ptq;
    int  ln;
    ln = strlen(pt);
    if(i >= ln) *pt = '\0';
    else{
      pta = pt;	ptq = pt + i;
      do{
	*(pta++) = *(ptq++);
      } while(*ptq);
      *pta = '\0';
    }
}

ptptcut(pt1, pt2)
char *pt1, *pt2;
{
    char *pta = pt1, *ptz = pt2;
    do{
      *(pta++) = *(++ptz);
    }	while(*ptz);
}

insertc(a, i, c, ln)
char a[], c;
int  i, ln;
{
    int  j;
    if(i < ln)
      for(j = ln; j > i; j--) a[j] = a[j-1];
    a[i] = c;	a[ln+1] = '\0';
}

ptinsert(pt, s)
char *pt, s[];
{
    char dums[2000];
    strcpy(dums, pt);	strcpy(pt, s);	strcat(pt, dums);
}

left(a, c, i)
char a[], c[];
int  i;
{
    int  x;
    if(i > strlen(c)) i = strlen(c);
    for(x = 0; x <= i-1; x++) a[x] = c[x];
    a[i] = '\0';
}

replaces(a, k, ln2, c)
char a[], c[];
int  k, ln2;
{
    char *bpt, dumc[2000];
    bpt = a + k + ln2;
    strcpy(dumc, c);	strcat(dumc, bpt);
    *(a+k) = '\0';	strcat(a, dumc);
}

ptreplace(pt, ln, c)
char c[], *pt;
int  ln;
{
    char *pt2 = pt+ln, dums[2000];
    strcpy(dums, pt2);	*pt = '\0';
    strink(pt, c, dums, (char*)0);
}

strink(s1, s2)
char *s1, *s2;
{
    char *p = s1, *q, **a = &s2;
    while(*p) ++p;
    while(q = *(a++)) while(*q) *p++ = *q++;
    *p = '\0';
}

right(c, b, i)
unsigned char *c, *b;
int  i;
{
    int  d;
    unsigned char *pt;
    if(i >= 0){
      d = strlen(c)-i;
      if(d >= 0) pt = c+d;	else pt = c;
      strcpy(b, pt);
    }
    else *b = '\0';
}

mid(a, i, j, b)
int  i, j;
char a[], b[];
{
    char c[2000];
    left(c, a, i+j-1);	right(c, b, j);
}

instr(a, b)
char *a, *b;
{
    int  j = 1;
    char *pt;
    if(pt = (char *)strstr(a, b)){
      while( a != pt--) j++;
      return(j);
    }
    else return(0);
}

ninstr(n, a, b)
int  n;
char *a, *b;
{
    int  inst;
    char *pta;
    pta = a+n-1;
    if(inst = instr(pta, b)) return(n+inst-1);
    else return(0);
}

instrc(a, b)
char *a, b;
{
    int  j = 1;
    char *pt;
    if(pt = (char *)index(a, b)){
      while(a != pt--) j++;
      return(j);
    }
    else return(0);
}

ninstrc(n, a, b)
int  n;
char *a, b;
{
    int  inst;
    char *pta;
    pta = a + n - 1;
    if(inst = instrc(pta, b)) return(n+inst-1);
    else return(0);
}

swap(a, b)
char a[], b[];
{
    char c[2000];
    strcpy(c, a);	strcpy(a, b);	strcpy(b, c);
}

val(nstr)
char nstr[];
{
    int  ln, i, keta = 1, n = 0;
    ln = strlen(nstr);
    for(i = ln-1; i >= 0; i--){
      n += (keta * (nstr[i]-'0'));	keta *= 10;
    }
    return(n);
}

zentoint(zenkaku)
char zenkaku[];
{
    int  i, ln, numb = 0, keta = 1;
    ln = strlen(zenkaku)/2-1;
    for(i = ln; i >= 0; i--){
      numb += keta*(zenkaku[i*2+1]-79);	keta *= 10;
    }
    return(numb);
}

nzentohan(zenkaku, hankaku)
char zenkaku[], hankaku[];
{
    int  i, ln;
    char ch;
    hankaku[0] = '\0';
    ln = strlen(zenkaku) / 2 - 1;
    for(i = 0; i <= ln; i++){
      ch = zenkaku[2 * i + 1] - 31;
      hankaku[i] = ch;
    }
    hankaku[++ln] = '\0';
}

nhantozen(hankaku,zenkaku)
char hankaku[], zenkaku[];
{
    int  i, ln;
    ln = strlen(hankaku)-1;
    for(i = 0; i <= ln; i++){
      if(hankaku[i] == ','){
	zenkaku[2*i] = '\0';	strcat(zenkaku, "C");
      }
      else{
	zenkaku[2*i] = -126;
	if(hankaku[1] < 97) zenkaku[2*i+1] = hankaku[i]+31;
	else zenkaku[2*i+1] = hankaku[i]-225;
      }
    }
    zenkaku[2*i] = '\0';
}

numbtohan(numb, hankaku)
int  numb;
char hankaku[];
{
    int  i, dig, ln;
    char invdigits[9];
    for(i = 0; ; i++){
      dig = numb % 10;
      invdigits[i] = dig +'0';
      numb -= dig;
      if(numb == 0) break;
      else numb /= 10;
    }
    ln = i;
    invdigits[ln+1] = '\0';
    for(i = 0; i <= ln; i++) hankaku[i] = invdigits[ln-i];
    hankaku[ln+1] = '\0';
}

// s1當s2P̂ݍ폜

void strdelc(char *s1, char *s2){
    char *p = s1; 

    p = strstr(s1, s2);
    if(p == NULL) return;
    strcpy(p, p+strlen(s2));
}

// s1ƕs2̐擪n byteƂ̔r Ԓl͈v̏ꍇpt sv̏ꍇ0

char *ptncmp(s1, s2, n)
char *s1, *s2;
int  n;
{
    char str[40], *pt;
    strncpy(str, s2, n);
    str[n] = '\0';
    pt = strstr(s1, str);
    if(strlen(str) == 0) pt = 0;
    //    if(Dbg == 'Y') fprintf(dbg, "--- ptncmp --- s1 = %s str = %s pt = %d \n", s1, str, pt);
    return(pt);
}

/*
strstr(str1, str2)
unsigned char *str1, *str2;
{
    int  str;
    str = (char*)str1;
    STRST:
    if(strlen(str) < strlen(str2)) return('\0');
	str = index(str, *str2);
    if(str == '\0') return('\0');
    if(strncmp(str, str2, strlen(str2))==0) return(str);
    str++;	goto STRST;
}
*/
/*------- predit ------------------------------------------*/


/*------- posted ------------------------------------------*/

/*
void InsertLF(char *buf, int n)
{
    int  flg, i;
    if(strlen(buf) > n+1){ flg = 0;
      for(i = 0; i < 6; i++){
        if(iskanji(buf[n-8+2*i]) && (!iskanji2(buf[n-8+2*i]))) flg = 1;
        if((! iskanji(buf[n-7+2*i])) && iskanji2(buf[n-7+2*i])) flg = 1;
      }
      if(flg == 1) ptinsert(buf+n, "\n");
      else ptinsert(buf+n-1, "\n");
    }
}
*/

==> j2e.2.3.tar.gz: jhonyakuf.c <==
// jhonyakuf.c
//
#include <string.h>
#include <stdio.h>
#include <ctype.h>
#include "macro.h"

#define iskanji(c) ((c)>=0x81 && (c)<=0x9f || (c)>=0xe0 && (c)<=0xfc)
#define iskanji2(c) ((c)>=0x40 && (c)<=0x7e || (c)>=0x80 && (c)<=0xfc)

//extern char *dir;
extern FILE *dbg;
extern char Dbg;
extern int  wnb;
extern char cj[][JSentLen];

isVowel(char c)
{
    int  j = 0;
    if(c == 'a' || c == 'e' || c == 'i' || c == 'o' || c == 'u') j = 1;
    if(c == 'A' || c == 'E' || c == 'I' || c == 'O' || c == 'U') j = 1;
    return(j);
}

ptcpy(c, pt1, pt2)
char c[], *pt1, *pt2;
{
     char *pt;
     pt = pt1;
     while(pt != pt2) *(c++) = *(pt++);
    *c = '\0';
}

wdcpy(char *st1, char *st2)
{
    while(*st2 && (*st2 != ' ')) *st1++ = *st2++;
    *st1 = '\0';
}

cutoff(a, x, i)
char *a;
int  x, i;
{
    int  ln;
    char *b;
    ln = strlen(a);
    if(x < ln){
      b = a+x+i;	*(a+x) = '\0';
      if(ln > x+1) strcat(a, b);
    }
}

ptcut(pt, i)
char *pt;
int  i;
{
    char *pta, *ptq;
    int  ln;
    ln = strlen(pt);
    if(i >= ln) *pt = '\0';
    else{
      pta = pt;	ptq = pt + i;
      do{
	*(pta++) = *(ptq++);
      } while(*ptq);
      *pta = '\0';
    }
}

ptptcut(pt1, pt2)
char *pt1, *pt2;
{
    char *pta = pt1, *ptz = pt2;
    do{
      *(pta++) = *(++ptz);
    }	while(*ptz);
}

insertc(a, i, c, ln)
char a[], c;
int  i, ln;
{
    int  j;
    if(i < ln)
      for(j = ln; j > i; j--) a[j] = a[j-1];
    a[i] = c;	a[ln+1] = '\0';
}

ptinsert(pt, s)
char *pt, s[];
{
    char dums[2000];
    strcpy(dums, pt);	strcpy(pt, s);	strcat(pt, dums);
}

left(a, c, i)
char a[], c[];
int  i;
{
    int  x;
    if(i > strlen(c)) i = strlen(c);
    for(x = 0; x <= i-1; x++) a[x] = c[x];
    a[i] = '\0';
}

replaces(a, k, ln2, c)
char a[], c[];
int  k, ln2;
{
    char *bpt, dumc[2000];
    bpt = a + k + ln2;
    strcpy(dumc, c);	strcat(dumc, bpt);
    *(a+k) = '\0';	strcat(a, dumc);
}

ptreplace(pt, ln, c)
char c[], *pt;
int  ln;
{
    char *pt2 = pt+ln, dums[2000];
    strcpy(dums, pt2);	*pt = '\0';
    strink(pt, c, dums, (char*)0);
}

strink(s1, s2)
char *s1, *s2;
{
    char *p = s1, *q, **a = &s2;
    while(*p) ++p;
    while(q = *(a++)) while(*q) *p++ = *q++;
    *p = '\0';
}

right(c, b, i)
unsigned char *c, *b;
int  i;
{
    int  d;
    unsigned char *pt;
    if(i >= 0){
      d = strlen(c)-i;
      if(d >= 0) pt = c+d;	else pt = c;
      strcpy(b, pt);
    }
    else *b = '\0';
}

mid(a, i, j, b)
int  i, j;
char a[], b[];
{
    char c[2000];
    left(c, a, i+j-1);	right(c, b, j);
}

instr(a, b)
char *a, *b;
{
    int  j = 1;
    char *pt;
    if(pt = (char *)strstr(a, b)){
      while( a != pt--) j++;
      return(j);
    }
    else return(0);
}

ninstr(n, a, b)
int  n;
char *a, *b;
{
    int  inst;
    char *pta;
    pta = a+n-1;
    if(inst = instr(pta, b)) return(n+inst-1);
    else return(0);
}

instrc(a, b)
char *a, b;
{
    int  j = 1;
    char *pt;
    if(pt = (char *)index(a, b)){
      while(a != pt--) j++;
      return(j);
    }
    else return(0);
}

ninstrc(n, a, b)
int  n;
char *a, b;
{
    int  inst;
    char *pta;
    pta = a + n - 1;
    if(inst = instrc(pta, b)) return(n+inst-1);
    else return(0);
}

swap(a, b)
char a[], b[];
{
    char c[2000];
    strcpy(c, a);	strcpy(a, b);	strcpy(b, c);
}

val(nstr)
char nstr[];
{
    int  ln, i, keta = 1, n = 0;
    ln = strlen(nstr);
    for(i = ln-1; i >= 0; i--){
      n += (keta * (nstr[i]-'0'));	keta *= 10;
    }
    return(n);
}

zentoint(zenkaku)
char zenkaku[];
{
    int  i, ln, numb = 0, keta = 1;
    ln = strlen(zenkaku)/2-1;
    for(i = ln; i >= 0; i--){
      numb += keta*(zenkaku[i*2+1]-79);	keta *= 10;
    }
    return(numb);
}

nzentohan(zenkaku, hankaku)
char zenkaku[], hankaku[];
{
    int  i, ln;
    char ch;
    hankaku[0] = '\0';
    ln = strlen(zenkaku) / 2 - 1;
    for(i = 0; i <= ln; i++){
      ch = zenkaku[2 * i + 1] - 31;
      hankaku[i] = ch;
    }
    hankaku[++ln] = '\0';
}

nhantozen(hankaku,zenkaku)
char hankaku[], zenkaku[];
{
    int  i, ln;
    ln = strlen(hankaku)-1;
    for(i = 0; i <= ln; i++){
      if(hankaku[i] == ','){
	zenkaku[2*i] = '\0';	strcat(zenkaku, "C");
      }
      else{
	zenkaku[2*i] = -126;
	if(hankaku[1] < 97) zenkaku[2*i+1] = hankaku[i]+31;
	else zenkaku[2*i+1] = hankaku[i]-225;
      }
    }
    zenkaku[2*i] = '\0';
}

numbtohan(numb, hankaku)
int  numb;
char hankaku[];
{
    int  i, dig, ln;
    char invdigits[9];
    for(i = 0; ; i++){
      dig = numb % 10;
      invdigits[i] = dig +'0';
      numb -= dig;
      if(numb == 0) break;
      else numb /= 10;
    }
    ln = i;
    invdigits[ln+1] = '\0';
    for(i = 0; i <= ln; i++) hankaku[i] = invdigits[ln-i];
    hankaku[ln+1] = '\0';
}

// s1當s2P̂ݍ폜

void strdelc(char *s1, char *s2){
    char *p = s1; 

    p = strstr(s1, s2);
    if(p == NULL) return;
    strcpy(p, p+strlen(s2));
}

// s1ƕs2̐擪n byteƂ̔r Ԓl͈v̏ꍇpt sv̏ꍇ0

char *ptncmp(s1, s2, n)
char *s1, *s2;
int  n;
{
    char str[40], *pt;
    strncpy(str, s2, n);
    str[n] = '\0';
    pt = strstr(s1, str);
    if(strlen(str) == 0) pt = 0;
    //    if(Dbg == 'Y') fprintf(dbg, "--- ptncmp --- s1 = %s str = %s pt = %d \n", s1, str, pt);
    return(pt);
}

/*
strstr(str1, str2)
unsigned char *str1, *str2;
{
    int  str;
    str = (char*)str1;
    STRST:
    if(strlen(str) < strlen(str2)) return('\0');
	str = index(str, *str2);
    if(str == '\0') return('\0');
    if(strncmp(str, str2, strlen(str2))==0) return(str);
    str++;	goto STRST;
}
*/
/*------- predit ------------------------------------------*/


/*------- posted ------------------------------------------*/

/*
void InsertLF(char *buf, int n)
{
    int  flg, i;
    if(strlen(buf) > n+1){ flg = 0;
      for(i = 0; i < 6; i++){
        if(iskanji(buf[n-8+2*i]) && (!iskanji2(buf[n-8+2*i]))) flg = 1;
        if((! iskanji(buf[n-7+2*i])) && iskanji2(buf[n-7+2*i])) flg = 1;
      }
      if(flg == 1) ptinsert(buf+n, "\n");
      else ptinsert(buf+n-1, "\n");
    }
}
*/

#ifdef __linux

#include <iconv.h>

// shift-jis̕textutf-8ɕϊĕ\
sjis2utf8(text)
char text[2000];
{
  char textout[2000];
  char *pin;
  char *pout;

  iconv_t cd;
  size_t ilen, rlen;

  // from shift-jis to utf-8
  cd = iconv_open("UTF-8", "SHIFT-JIS");
  if(cd == (iconv_t)-1){
    perror("iconv open");  return  -1;
  }
  ilen = strlen(text);
  rlen = sizeof(textout)-1;
  pin = text;
  pout = textout;
  rlen = iconv(cd, &pin, &ilen, &pout, &rlen);
  if(rlen == -1){
    perror("iconv");  return -1;
  }
  *pout = '\0';
  iconv_close(cd);

  printf("%s\n", textout);
}

#endif
